<?php

namespace Litecms\OtherService\Http\Controllers;

use App\Http\Controllers\Controller as BaseController;
use Litecms\OtherService\Http\Requests\OtherServicesRequest;
use Litecms\OtherService\Models\OtherServices;

/**
 * Admin web controller class.
 */
class OtherServicesWorkflowController extends BaseController
{

    /**
     * Workflow controller function for other_services.
     *
     * @param Model   $other_services
     * @param step    next step for the workflow.
     *
     * @return Response
     */

    public function putWorkflow(OtherServicesRequest $request, OtherServices $other_services, $step)
    {

        try {

            $other_services->updateWorkflow($step);

            return response()->json([
                'message'  => trans('messages.success.changed', ['Module' => trans('other_service::other_services.name'), 'status' => trans("app.{$step}")]),
                'code'     => 204,
                'redirect' => trans_url('/admin/other_services/other_services/' . $other_services->getRouteKey()),
            ], 201);

        } catch (Exception $e) {

            return response()->json([
                'message'  => $e->getMessage(),
                'code'     => 400,
                'redirect' => trans_url('/admin/other_services/other_services/' . $other_services->getRouteKey()),
            ], 400);

        }

    }

    /**
     * Workflow controller function for other_services.
     *
     * @param Model   $other_services
     * @param step    next step for the workflow.
     * @param user    encrypted user id.
     *
     * @return Response
     */

    public function getWorkflow(OtherServices $other_services, $step, $user)
    {
        try {
            $user_id = decrypt($user);

            Auth::onceUsingId($user_id);

            $other_services->updateWorkflow($step);

            $data = [
                'message' => trans('messages.success.changed', ['Module' => trans('other_service::other_services.name'), 'status' => trans("app.{$step}")]),
                'status'  => 'success',
                'step'    => trans("app.{$step}"),
            ];

            return $this->theme->layout('blank')->of('other_service::admin.other_services.message', $data)->render();

        } catch (ValidationException $e) {

            $data = [
                'message' => '<b>' . $e->getMessage() . '</b> <br /><br />' . implode('<br />', $e->validator->errors()->all()),
                'status'  => 'error',
                'step'    => trans("app.{$step}"),
            ];

            return $this->theme->layout('blank')->of('other_service::admin.other_services.message', $data)->render();

        } catch (Exception $e) {

            $data = [
                'message' => '<b>' . $e->getMessage() . '</b>',
                'status'  => 'error',
                'step'    => trans("app.{$step}"),
            ];

            return $this->theme->layout('blank')->of('other_service::admin.other_services.message', $data)->render();

        }

    }
}
