<?php

namespace Litecms\OtherService\Policies;

use Litepie\User\Contracts\UserPolicy;
use Litecms\OtherService\Models\OtherServices;

class OtherServicesPolicy
{

    /**
     * Determine if the given user can view the other_services.
     *
     * @param UserPolicy $user
     * @param OtherServices $other_services
     *
     * @return bool
     */
    public function view(UserPolicy $user, OtherServices $other_services)
    {
        if ($user->canDo('other_service.other_services.view') && $user->isAdmin()) {
            return true;
        }

        return $other_services->user_id == user_id() && $other_services->user_type == user_type();
    }

    /**
     * Determine if the given user can create a other_services.
     *
     * @param UserPolicy $user
     * @param OtherServices $other_services
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('other_service.other_services.create');
    }

    /**
     * Determine if the given user can update the given other_services.
     *
     * @param UserPolicy $user
     * @param OtherServices $other_services
     *
     * @return bool
     */
    public function update(UserPolicy $user, OtherServices $other_services)
    {
        if ($user->canDo('other_service.other_services.edit') && $user->isAdmin()) {
            return true;
        }

        return $other_services->user_id == user_id() && $other_services->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given other_services.
     *
     * @param UserPolicy $user
     * @param OtherServices $other_services
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, OtherServices $other_services)
    {
        return $other_services->user_id == user_id() && $other_services->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given other_services.
     *
     * @param UserPolicy $user
     * @param OtherServices $other_services
     *
     * @return bool
     */
    public function verify(UserPolicy $user, OtherServices $other_services)
    {
        if ($user->canDo('other_service.other_services.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given other_services.
     *
     * @param UserPolicy $user
     * @param OtherServices $other_services
     *
     * @return bool
     */
    public function approve(UserPolicy $user, OtherServices $other_services)
    {
        if ($user->canDo('other_service.other_services.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
