<?php

namespace Litecms\OtherService\Providers;

use Illuminate\Support\ServiceProvider;

class OtherServiceServiceProvider extends ServiceProvider
{
    /**
     * Indicates if loading of the provider is deferred.
     *
     * @var bool
     */
    protected $defer = false;

    /**
     * Bootstrap the application events.
     *
     * @return void
     */
    public function boot()
    {
        // Load view
        $this->loadViewsFrom(__DIR__ . '/../../resources/views', 'other_service');

        // Load translation
        $this->loadTranslationsFrom(__DIR__ . '/../../resources/lang', 'other_service');

        // Load migrations
        $this->loadMigrationsFrom(__DIR__ . '/../../database/migrations');

        // Call pblish redources function
        $this->publishResources();

    }

    /**
     * Register the service provider.
     *
     * @return void
     */
    public function register()
    {
        // Bind facade
        $this->app->bind('litecms.other_service', function ($app) {
            return $this->app->make('Litecms\OtherService\OtherService');
        });

                // Bind OtherServices to repository
        $this->app->bind(
            'Litecms\OtherService\Interfaces\OtherServicesRepositoryInterface',
            \Litecms\OtherService\Repositories\Eloquent\OtherServicesRepository::class
        );

        $this->app->register(\Litecms\OtherService\Providers\AuthServiceProvider::class);
                $this->app->register(\Litecms\OtherService\Providers\EventServiceProvider::class);
        
        $this->app->register(\Litecms\OtherService\Providers\RouteServiceProvider::class);
                $this->app->register(\Litecms\OtherService\Providers\WorkflowServiceProvider::class);
                
    }

    /**
     * Get the services provided by the provider.
     *
     * @return array
     */
    public function provides()
    {
        return ['litecms.other_service'];
    }

    /**
     * Publish resources.
     *
     * @return void
     */
    private function publishResources()
    {
        // Publish configuration file
        $this->publishes([__DIR__ . '/../../config/config.php' => config_path('litecms/other_service.php')], 'config');

        // Publish admin view
        $this->publishes([__DIR__ . '/../../resources/views' => base_path('resources/views/vendor/other_service')], 'view');

        // Publish language files
        $this->publishes([__DIR__ . '/../../resources/lang' => base_path('resources/lang/vendor/other_service')], 'lang');

        // Publish public files and assets.
        $this->publishes([__DIR__ . '/public/' => public_path('/')], 'public');
    }
}
