<?php

namespace Litecms\OtherService\Workflow;

use Litecms\OtherService\Models\OtherServices;
use Validator;

class OtherServicesValidator
{

    /**
     * Determine if the given other_services is valid for complete status.
     *
     * @param OtherServices $other_services
     *
     * @return bool / Validator
     */
    public function complete(OtherServices $other_services)
    {
        return Validator::make($other_services->toArray(), [
            'title' => 'required|min:15',
        ]);
    }

    /**
     * Determine if the given other_services is valid for verify status.
     *
     * @param OtherServices $other_services
     *
     * @return bool / Validator
     */
    public function verify(OtherServices $other_services)
    {
        return Validator::make($other_services->toArray(), [
            'title'  => 'required|min:15',
            'status' => 'in:complete',
        ]);
    }

    /**
     * Determine if the given other_services is valid for approve status.
     *
     * @param OtherServices $other_services
     *
     * @return bool / Validator
     */
    public function approve(OtherServices $other_services)
    {
        return Validator::make($other_services->toArray(), [
            'title'  => 'required|min:15',
            'status' => 'in:verify',
        ]);

    }

    /**
     * Determine if the given other_services is valid for publish status.
     *
     * @param OtherServices $other_services
     *
     * @return bool / Validator
     */
    public function publish(OtherServices $other_services)
    {
        return Validator::make($other_services->toArray(), [
            'title'       => 'required|min:15',
            'description' => 'required|min:50',
            'status'      => 'in:approve,archive,unpublish',
        ]);

    }

    /**
     * Determine if the given other_services is valid for archive status.
     *
     * @param OtherServices $other_services
     *
     * @return bool / Validator
     */
    public function archive(OtherServices $other_services)
    {
        return Validator::make($other_services->toArray(), [
            'title'       => 'required|min:15',
            'description' => 'required|min:50',
            'status'      => 'in:approve,publish,unpublish',
        ]);

    }

    /**
     * Determine if the given other_services is valid for unpublish status.
     *
     * @param OtherServices $other_services
     *
     * @return bool / Validator
     */
    public function unpublish(OtherServices $other_services)
    {
        return Validator::make($other_services->toArray(), [
            'title'       => 'required|min:15',
            'description' => 'required|min:50',
            'status'      => 'in:publish',
        ]);

    }
}
